Index: webkit/fileapi/sandbox_mount_point_provider.h |
=================================================================== |
--- webkit/fileapi/sandbox_mount_point_provider.h (revision 80410) |
+++ webkit/fileapi/sandbox_mount_point_provider.h (working copy) |
@@ -6,6 +6,7 @@ |
#define WEBKIT_FILEAPI_SANDBOX_MOUNT_POINT_PROVIDER_H_ |
#include <string> |
+#include <vector> |
#include "base/file_path.h" |
#include "googleurl/src/gurl.h" |
@@ -28,8 +29,11 @@ |
const FilePath& profile_path); |
virtual ~SandboxMountPointProvider(); |
- // Checks if mount point access is allowed from |origin_url|. |
- virtual bool IsAccessAllowed(const GURL& origin_url); |
+ // Checks if access to |virtual_path| is allowed from |origin_url|. |
+ virtual bool IsAccessAllowed(const GURL& origin_url, |
+ const FilePath& virtual_path); |
+ virtual void GrantAccess(const GURL& origin_url, |
+ const FilePath& virtual_path) {} |
ericu
2011/04/07 01:40:58
Should this ever get called? How about a NOTREACH
zel
2011/04/07 02:54:42
Done.
|
// Retrieves the root path for the given |origin_url| and |type|, and |
// calls the given |callback| with the root path and name. |
@@ -61,6 +65,10 @@ |
// Checks if a given |name| contains any restricted names/chars in it. |
virtual bool IsRestrictedFileName(const FilePath& filename) const; |
+ virtual std::vector<FilePath> GetRootDirectories() const { |
+ return std::vector<FilePath>(); |
ericu
2011/04/07 01:40:58
Same here. Perhaps these shouldn't really live on
zel
2011/04/07 02:54:42
I've added NOTREACHED() here. Done.
|
+ } |
+ |
// Returns the origin identifier string, which is used as a part of the |
// sandboxed path component, for the given |url|. |
static std::string GetOriginIdentifierFromURL(const GURL& url); |